@@ -56,7 +56,7 @@ namespace KFTPBookmarks {
  */
 class KFTPWalletAction : public TDEAction
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KFTPWalletAction(const TQString &text, const TQString &pix, const TDEShortcut &cut, const TQObject *receiver, const char *slot, TDEActionCollection *parent, const char *name = 0);
   
@@ -74,7 +74,7 @@ private:
  */
 class KFTPZeroconfAction : public TDEAction
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KFTPZeroconfAction(const TQString &text, const TQString &pix, const TDEShortcut &cut, const TQObject *receiver, const char *slot, TDEActionCollection *parent, const char *name = 0);
     void setSite(DNSSD::RemoteService::Ptr service);
@@ -91,7 +91,7 @@ private:
  */
 class KFTPBookmarkAction : public TDEAction
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KFTPBookmarkAction(const TQString &text, const TQString &pix, const TDEShortcut &cut, const TQObject *receiver, const char *slot, TDEActionCollection *parent, const char *name = 0);
     
